##
##  softhsm.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2019 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
Name:         softhsm
Summary:      Software High Security Module (HSM)
URL:          http://www.opendnssec.org/softhsm/
Vendor:       OpenDNSSEC AB
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        EVAL
Group:        Security
License:      MIT
Version:      2.5.0
Release:      20190424

#   list of sources
Source0:      http://www.opendnssec.org/files/source/softhsm-%{version}.tar.gz
Patch0:       softhsm.patch

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, gcc, gcc::with_cxx = yes, pkgconfig
PreReq:       OpenPKG, openpkg >= 20160101
BuildPreReq:  sqlite, openssl, p11kit
PreReq:       sqlite, openssl, p11kit

%description
    SoftHSM is an implementation of a cryptographic store accessible
    through a PKCS #11 interface. You can use it to explore PKCS #11
    without having a Hardware Security Module. It is being developed
    as a part of the OpenDNSSEC project. SoftHSM uses Botan for its
    cryptographic operations.

%track
    prog softhsm = {
        version   = %{version}
        url       = http://www.opendnssec.org/download/
        regex     = softhsm-(\d+\.\d+\.\d+)\.tar\.gz
    }

%prep
    %setup -q
    %patch -p0

%build
    CC="%{l_cc}" \
    CFLAGS="%{l_cflags -O}" \
    CPPFLAGS="%{l_cppflags}" \
    LDFLAGS="%{l_ldflags}" \
    LIBS="-lm" \
    ./configure \
        --prefix=%{l_prefix} \
        --sysconfdir=%{l_prefix}/etc/softhsm \
        --mandir=%{l_prefix}/man \
        --with-crypto-backend=openssl \
        --with-openssl=%{l_prefix} \
        --with-sqlite3=%{l_prefix} \
        --enable-p11-kit \
        --enable-shared
    %{l_make} %{l_mflags -O}

%install
    %{l_make} %{l_mflags} install AM_MAKEFLAGS="DESTDIR=$RPM_BUILD_ROOT"
    rm -f $RPM_BUILD_ROOT%{l_prefix}/etc/softhsm/*.sample >/dev/null 2>&1 || true
    rm -rf $RPM_BUILD_ROOT%{l_prefix}/var
    strip $RPM_BUILD_ROOT%{l_prefix}/bin/* >/dev/null 2>&1 || true
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT \
        %{l_files_std} \
        '%config %{l_prefix}/etc/softhsm/*'

%files -f files

%clean

